OC.L10N.register(
    "core",
    {
    "Please select a file." : "ھۆججەت تاللاڭ.",
    "File is too big" : "ھۆججەت بەك چوڭ",
    "The selected file is not an image." : "تاللانغان ھۆججەت رەسىم ئەمەس.",
    "The selected file cannot be read." : "تاللانغان ھۆججەتنى ئوقۇغىلى بولمايدۇ.",
    "The file was uploaded" : "ھۆججەت يۈكلەندى",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "يۈكلەنگەن ھۆججەت php.ini دىكى upload_max_filesize كۆرسەتمىسىدىن ئېشىپ كەتتى",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "يۈكلەنگەن ھۆججەت HTML شەكلىدە كۆرسىتىلگەن MAX_FILE_SIZE كۆرسەتمىسىدىن ئېشىپ كەتتى",
    "The file was only partially uploaded" : "بۇ ھۆججەت پەقەت قىسمەن يوللانغان",
    "No file was uploaded" : "ھېچقانداق ھۆججەت يۈكلەنمىدى",
    "Missing a temporary folder" : "ۋاقىتلىق قىسقۇچ كەم.",
    "Could not write file to disk" : "دىسكىغا ھۆججەت يازالمىدى",
    "A PHP extension stopped the file upload" : "PHP كېڭەيتىلمىسى ھۆججەت يوللاشنى توختاتتى",
    "Invalid file provided" : "ئىناۋەتسىز ھۆججەت تەمىنلەندى",
    "No image or file provided" : "رەسىم ياكى ھۆججەت تەمىنلەنمىگەن",
    "Unknown filetype" : "نامەلۇم ھۆججەت شەكلى",
    "An error occurred. Please contact your admin." : "خاتالىق كۆرۈلدى. باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
    "Invalid image" : "ئىناۋەتسىز رەسىم",
    "No temporary profile picture available, try again" : "ۋاقىتلىق ئارخىپ رەسىمى يوق ، قايتا سىناڭ",
    "No crop data provided" : "زىرائەت سانلىق مەلۇماتلىرى تەمىنلەنمىدى",
    "No valid crop data provided" : "ئۈنۈملۈك زىرائەت سانلىق مەلۇماتلىرى تەمىنلەنمىدى",
    "Crop is not square" : "زىرائەت چاسا ئەمەس",
    "State token does not match" : "دۆلەت بەلگىسى ماس كەلمەيدۇ",
    "Invalid app password" : "ئىناۋەتلىك ئەپ مەخپىي نومۇرى",
    "Could not complete login" : "كىرىشنى تاماملىيالمىدى",
    "State token missing" : "دۆلەت بەلگىسى يوقاپ كەتتى",
    "Your login token is invalid or has expired" : "كىرىش بەلگىڭىز ئىناۋەتسىز ياكى ۋاقتى توشتى",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Nextcloud نىڭ بۇ مەھەللە تارقىتىلىشى قوللىمايدۇ ، ئىتتىرىش ئۇقتۇرۇشى چەكلىك.",
    "Login" : "Login",
    "Unsupported email length (>255)" : "قوللىمايدىغان ئېلېكترونلۇق خەتنىڭ ئۇزۇنلۇقى (> 255)",
    "Password reset is disabled" : "پارولنى ئەسلىگە كەلتۈرۈش چەكلەنگەن",
    "Could not reset password because the token is expired" : "بەلگە ۋاقتى توشقانلىقتىن پارولنى ئەسلىگە كەلتۈرەلمىدى",
    "Could not reset password because the token is invalid" : "بەلگە ئىناۋەتسىز بولغاچقا پارولنى ئەسلىگە كەلتۈرەلمىدى",
    "Password is too long. Maximum allowed length is 469 characters." : "پارول بەك ئۇزۇن. رۇخسەت قىلىنغان ئەڭ ئۇزۇن ئۇزۇنلۇقى 469 ھەرپ.",
    "%s password reset" : "% s پارولنى ئەسلىگە كەلتۈرۈش",
    "Password reset" : "پارولنى ئەسلىگە كەلتۈرۈش",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "پارولىڭىزنى ئەسلىگە كەلتۈرۈش ئۈچۈن تۆۋەندىكى كۇنۇپكىنى بېسىڭ. ئەگەر پارولنى ئەسلىگە كەلتۈرۈشنى تەلەپ قىلمىغان بولسىڭىز ، ئۇنداقتا بۇ ئېلېكترونلۇق خەتكە پەرۋا قىلماڭ.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "پارولىڭىزنى قايتا بەلگىلەش ئۈچۈن تۆۋەندىكى ئۇلانمىنى چېكىڭ. ئەگەر پارولنى ئەسلىگە كەلتۈرۈشنى تەلەپ قىلمىغان بولسىڭىز ، ئۇنداقتا بۇ ئېلېكترونلۇق خەتكە پەرۋا قىلماڭ.",
    "Reset your password" : "پارولىڭىزنى ئەسلىگە كەلتۈرۈڭ",
    "The given provider is not available" : "بېرىلگەن تەمىنلىگۈچىنى ئىشلەتكىلى بولمايدۇ",
    "Task not found" : "ۋەزىپە تېپىلمىدى",
    "Internal error" : "ئىچكى خاتالىق",
    "Not found" : "تېپىلمىدى",
    "Bad request" : "ناچار تەلەپ",
    "Requested task type does not exist" : "تەلەپ قىلىنغان ۋەزىپە تىپى مەۋجۇت ئەمەس",
    "Necessary language model provider is not available" : "زۆرۈر تىل مودېل تەمىنلىگۈچىنى ئىشلەتكىلى بولمايدۇ",
    "No text to image provider is available" : "رەسىم تەمىنلىگۈچىگە ھېچقانداق تېكىست يوق",
    "Image not found" : "رەسىم تېپىلمىدى",
    "No translation provider available" : "تەرجىمە تەمىنلىگۈچى يوق",
    "Could not detect language" : "تىلنى بايقىيالمىدى",
    "Unable to translate" : "تەرجىمە قىلالمىدى",
    "[%d / %d]: %s" : "[% d /% d]:% s",
    "Repair step:" : "رېمونت قىلىش باسقۇچى:",
    "Repair info:" : "رېمونت ئۇچۇرى:",
    "Repair warning:" : "رېمونت ئاگاھلاندۇرۇشى:",
    "Repair error:" : "رېمونت خاتالىقى:",
    "Nextcloud Server" : "Nextcloud مۇلازىمىتىرى",
    "Some of your link shares have been removed" : "بەزى ئۇلىنىشلىرىڭىز ئۆچۈرۈلدى",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "بىخەتەرلىك خاتالىقى سەۋەبىدىن بەزى ئۇلىنىشلىرىڭىزنى ئۆچۈرۈۋەتتۇق. تېخىمۇ كۆپ ئۇچۇرغا ئېرىشىش ئۈچۈن ئۇلىنىشنى كۆرۈڭ.",
    "The account limit of this instance is reached." : "بۇ مىسالنىڭ ھېسابات چېكىگە يەتتى.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "ھېسابات چەكلىمىسىنى ئاشۇرۇش ئۈچۈن مۇشتەرىلىك ئاچقۇچىڭىزنى قوللاش دېتالىغا كىرگۈزۈڭ. بۇ سىزگە Nextcloud كارخانا تەمىنلىگەن بارلىق قوشۇمچە پايدىلارنى بېرىدۇ ھەمدە شىركەتلەردە مەشغۇلات قىلىشقا تەۋسىيە قىلىنىدۇ.",
    "Learn more ↗" : "تەپسىلاتى ↗",
    "Preparing update" : "يېڭىلاش تەييارلىقى",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "بۇيرۇق قۇرىنى يېڭىلاشنى ئىشلىتىڭ ، چۈنكى config.php دا توركۆرگۈ ئارقىلىق يېڭىلاش چەكلەنگەن.",
    "Turned on maintenance mode" : "ئاسراش ھالىتىنى ئاچتى",
    "Turned off maintenance mode" : "ئاسراش ھالىتىنى ئېتىۋەتتى",
    "Maintenance mode is kept active" : "ئاسراش ھالىتى ئاكتىپ ھالەتتە ساقلىنىدۇ",
    "Updating database schema" : "ساندان لايىھىسىنى يېڭىلاش",
    "Updated database" : "ساندان يېڭىلاندى",
    "Update app \"%s\" from App Store" : "ئەپ دۇكىنىدىن «% s» دېتالىنى يېڭىلاڭ",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "% S نىڭ ساندان لايىھىسىنى يېڭىلاشقا بولىدىغان-بولمايدىغانلىقىنى تەكشۈرۈش (بۇ سانداننىڭ چوڭ-كىچىكلىكىگە ئاساسەن ئۇزۇن ۋاقىت كېتىدۇ)",
    "Updated \"%1$s\" to %2$s" : "\"%1 $ s\" نى%2 $ s غا يېڭىلىدى",
    "Set log level to debug" : "خاتىرە دەرىجىسىنى تەڭشەشكە تەڭشەڭ",
    "Reset log level" : "خاتىرە دەرىجىسىنى ئەسلىگە كەلتۈرۈڭ",
    "Starting code integrity check" : "كود پۈتۈنلۈكىنى تەكشۈرۈشنى باشلاش",
    "Finished code integrity check" : "كود مۇكەممەللىكىنى تەكشۈرۈش تاماملاندى",
    "%s (incompatible)" : "% s (ماس كەلمەيدۇ)",
    "The following apps have been disabled: %s" : "تۆۋەندىكى ئەپلەر چەكلەنگەن:% s",
    "Already up to date" : "ئاللىبۇرۇن يېڭىلاندى",
    "Unknown" : "نامەلۇم",
    "unknown text" : "نامەلۇم تېكىست",
    "Hello world!" : "ياخشىمۇسىز دۇنيا!",
    "sunny" : "ئاپتاپپەرەس",
    "Hello {name}, the weather is {weather}" : "ياخشىمۇسىز {name} ، ھاۋارايى {weather}",
    "Hello {name}" : "ياخشىمۇسىز {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong> بۇلار سىزنىڭ ئىزدەش نەتىجىلىرىڭىز <script> ئاگاھلاندۇرۇش (1) </script> </strong>",
    "new" : "new",
    "The update is in progress, leaving this page might interrupt the process in some environments." : "يېڭىلاش ئېلىپ بېرىلىۋاتىدۇ ، بۇ بەتتىن ئايرىلىش بەزى مۇھىتتىكى جەرياننى قالايمىقانلاشتۇرۇشى مۇمكىن.",
    "Update to {version}" : "{version} يېڭىلاش}",
    "An error occurred." : "خاتالىق كۆرۈلدى.",
    "Please reload the page." : "بۇ بەتنى قايتا يۈكلەڭ.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "يېڭىلاش مۇۋەپپەقىيەتلىك بولمىدى. تېخىمۇ كۆپ ئۇچۇرغا ئېرىشىش ئۈچۈن <a href = \"{url}\"> بۇ مەسىلىنى ئۆز ئىچىگە ئالغان مۇنبەر يازمىمىزنى تەكشۈرۈڭ </a>.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "يېڭىلاش مۇۋەپپەقىيەتلىك بولمىدى. بۇ مەسىلىنى <a href = \"https://github.com/nextcloud/server/issues\" target = \"_ blank\"> Nextcloud مەھەللىسىگە دوكلات قىلىڭ.",
    "Continue to {productName}" : "داۋاملاشتۇرۇش {productName}",
    "Applications menu" : "قوللىنىشچان تىزىملىك",
    "Apps" : "ئەپلەر",
    "More apps" : "تېخىمۇ كۆپ ئەپلەر",
    "No" : "ياق",
    "Yes" : "ھەئە",
    "The remote URL must include the user." : "يىراقتىكى URL چوقۇم ئىشلەتكۈچىنى ئۆز ئىچىگە ئېلىشى كېرەك.",
    "Invalid remote URL." : "يىراقتىكى URL ئىناۋەتسىز.",
    "Failed to add the public link to your Nextcloud" : "Nextcloud غا ئاممىۋى ئۇلىنىشنى قوشالمىدى",
    "Federated user" : "فېدېراتسىيە ئىشلەتكۈچى",
    "user@your-nextcloud.org" : "user@your-nextcloud.org",
    "Create share" : "ئورتاقلىشىش",
    "Please copy the link manually:" : "ئۇلىنىشنى قولدا كۆچۈرۈڭ:",
    "Custom date range" : "ئىختىيارى چېسلا دائىرىسى",
    "Pick start date" : "باشلىنىش ۋاقتىنى تاللاڭ",
    "Pick end date" : "ئاخىرلىشىش ۋاقتىنى تاللاڭ",
    "Search in date range" : "چېسلا دائىرىسىدىن ئىزدەڭ",
    "Search in current app" : "نۆۋەتتىكى ئەپتىن ئىزدەڭ",
    "Clear search" : "ئىزدەشنى تازىلاش",
    "Search everywhere" : "ھەممە يەردىن ئىزدەڭ",
    "Searching …" : "ئىزدەش…",
    "Start typing to search" : "ئىزدەشنى باشلاڭ",
    "No matching results" : "ماس كېلىدىغان نەتىجە يوق",
    "Today" : "بۈگۈن",
    "Last 7 days" : "ئاخىرقى 7 كۈن",
    "Last 30 days" : "ئاخىرقى 30 كۈن",
    "This year" : "بۇ يىل",
    "Last year" : "ئۆتكەن يىلى",
    "Unified search" : "بىرلىككە كەلگەن ئىزدەش",
    "Search apps, files, tags, messages" : "ئەپ ، ھۆججەت ، بەلگە ، ئۇچۇرلارنى ئىزدەڭ",
    "Places" : "جايلار",
    "Date" : "چېسلا",
    "Search people" : "كىشىلەرنى ئىزدەڭ",
    "People" : "كىشىلەر",
    "Filter in current view" : "نۆۋەتتىكى كۆرۈنۈشتە سۈزۈڭ",
    "Results" : "نەتىجە",
    "Load more results" : "تېخىمۇ كۆپ نەتىجىلەرنى يۈكلەڭ",
    "Search in" : "ئىزدەڭ",
    "Log in" : "كىرىڭ",
    "Logging in …" : "تىزىمغا كىرىش…",
    "Log in to {productName}" : "{productName} to غا كىرىڭ",
    "Wrong login or password." : "كىرىش ياكى پارول خاتا.",
    "This account is disabled" : "بۇ ھېسابات چەكلەنگەن",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "بىز IP دىن نۇرغۇن ئىناۋەتسىز كىرىش سىنىقىنى بايقىدۇق. شۇڭلاشقا كېيىنكى كىرىش ۋاقتىڭىز 30 سېكۇنتقا يېتىدۇ.",
    "Account name or email" : "ھېسابات ئىسمى ياكى ئېلېكترونلۇق خەت",
    "Account name" : "ھېسابات ئىسمى",
    "Server side authentication failed!" : "مۇلازىمېتىر تەرەپ دەلىللەش مەغلۇپ بولدى!",
    "Please contact your administrator." : "باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
    "An internal error occurred." : "ئىچكى خاتالىق كۆرۈلدى.",
    "Please try again or contact your administrator." : "قايتا سىناڭ ياكى باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
    "Password" : "ئىم",
    "Log in with a device" : "ئۈسكۈنە بىلەن كىرىڭ",
    "Login or email" : "كىرىش ياكى ئېلخەت",
    "Your account is not setup for passwordless login." : "ھېساباتىڭىز پارولسىز كىرىش ئۈچۈن تەڭشەلمىدى.",
    "Your connection is not secure" : "ئۇلىنىشىڭىز بىخەتەر ئەمەس",
    "Passwordless authentication is only available over a secure connection." : "پارولسىز دەلىللەش پەقەت بىخەتەر ئۇلىنىش ئارقىلىقلا بولىدۇ.",
    "Browser not supported" : "توركۆرگۈ قوللىمايدۇ",
    "Passwordless authentication is not supported in your browser." : "توركۆرگۈڭىزدە پارولسىز دەلىللەشنى قوللىمايدۇ.",
    "Reset password" : "پارولنى ئەسلىگە قايتۇرۇش",
    "Back to login" : "قايتا كىرىش",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "ئەگەر بۇ ھېسابات مەۋجۇت بولسا ، ئېلېكترونلۇق خەت ئادرېسىغا پارولنى ئەسلىگە كەلتۈرۈش ئۇچۇرى ئەۋەتىلدى. ئەگەر ئۇنى تاپشۇرۇۋالمىسىڭىز ، ئېلېكترونلۇق خەت ئادرېسىڭىزنى ۋە ياكى ياكى تىزىملىتىپ كىرىڭ ، ئەخلەت خەت ساندۇقىڭىزنى تەكشۈرۈڭ ياكى يەرلىك ھۆكۈمەتتىن ياردەم سوراڭ.",
    "Couldn't send reset email. Please contact your administrator." : "قايتا ئېلېكترونلۇق خەت ئەۋەتەلمىدى. باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
    "Password cannot be changed. Please contact your administrator." : "پارولنى ئۆزگەرتىشكە بولمايدۇ. باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
    "New password" : "يېڭى ئىم",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "ھۆججەتلىرىڭىز شىفىرلانغان. پارولىڭىز ئەسلىگە كەلگەندىن كېيىن سانلىق مەلۇماتلىرىڭىزنى قايتۇرۇۋېلىشقا ئامال يوق. نېمە قىلىشنى بىلمىسىڭىز ، داۋاملاشتۇرۇشتىن بۇرۇن باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ. داۋاملاشتۇرۇشنى خالامسىز؟",
    "I know what I'm doing" : "نېمە قىلىۋاتقانلىقىمنى بىلىمەن",
    "Resetting password" : "پارولنى ئەسلىگە كەلتۈرۈش",
    "Schedule work & meetings, synced with all your devices." : "بارلىق ئۈسكۈنىلىرىڭىز بىلەن ماس قەدەملىك خىزمەت ۋە يىغىنلارنى ئورۇنلاشتۇرۇڭ.",
    "Keep your colleagues and friends in one place without leaking their private info." : "خىزمەتداشلىرىڭىزنى ۋە دوستلىرىڭىزنى شەخسىي ئۇچۇرلىرىنى ئاشكارىلىماي بىر جايدا ساقلاڭ.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "ئاددىي ئېلېكترونلۇق خەت دېتالى ھۆججەتلەر ، ئالاقىداشلار ۋە كالېندار بىلەن چىرايلىق بىرلەشتۈرۈلگەن.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "كوللابورا تورىدا قۇرۇلغان ھەمكارلىق ھۆججەتلىرى ، ئېلېكترونلۇق جەدۋەل ۋە تونۇشتۇرۇشلار.",
    "Distraction free note taking app." : "دىققىتى چېچىلىدىغان ھەقسىز خاتىرە ئېلىش دېتالى.",
    "Recommended apps" : "تەۋسىيە قىلىنغان ئەپلەر",
    "Loading apps …" : "ئەپلەرنى يۈكلەۋاتىدۇ…",
    "Could not fetch list of apps from the App Store." : "ئەپ دۇكىنىدىن ئەپلەرنىڭ تىزىملىكىنى ئالالمىدى.",
    "App download or installation failed" : "ئەپ چۈشۈرۈش ياكى قاچىلاش مەغلۇب بولدى",
    "Cannot install this app because it is not compatible" : "ماس كەلمىگەچكە بۇ ئەپنى قاچىلىغىلى بولمايدۇ",
    "Cannot install this app" : "بۇ ئەپنى قاچىلىغىلى بولمايدۇ",
    "Skip" : "ئاتلاش",
    "Installing apps …" : "ئەپلەرنى قاچىلاش…",
    "Install recommended apps" : "تەۋسىيە قىلىنغان ئەپلەرنى قاچىلاڭ",
    "Avatar of {displayName}" : "Av displayName of نىڭ باش سۈرىتى",
    "Settings menu" : "تەڭشەك تىزىملىكى",
    "Loading your contacts …" : "ئالاقىداشلىرىڭىزنى يۈكلەۋاتىدۇ…",
    "Looking for {term} …" : "ئىزدەۋاتقان {term}…",
    "Search contacts" : "ئالاقىداشلارنى ئىزدە",
    "Reset search" : "ئىزدەشنى ئەسلىگە كەلتۈرۈڭ",
    "Search contacts …" : "ئالاقىداشلارنى ئىزدەش…",
    "Could not load your contacts" : "ئالاقىداشلىرىڭىزنى يۈكلىيەلمىدى",
    "No contacts found" : "ئالاقىداش تېپىلمىدى",
    "Show all contacts" : "بارلىق ئالاقىنى كۆرسەت",
    "Install the Contacts app" : "ئالاقىلىشىش دېتالىنى قاچىلاڭ",
    "Search" : "ئىزدە",
    "No results for {query}" : "{query} نەتىجىسى يوق",
    "Press Enter to start searching" : "Enter نى بېسىپ ئىزدەشنى باشلاڭ",
    "An error occurred while searching for {type}" : "{type} نى ئىزدەۋاتقاندا خاتالىق كۆرۈلدى",
    "Search starts once you start typing and results may be reached with the arrow keys" : "ئىزدەشنى باشلىغاندىن كېيىن ئىزدەش باشلىنىدۇ ، يا ئوق كۇنۇپكىسى بىلەن نەتىجىگە ئېرىشكىلى بولىدۇ",
    "Search for {name} only" : "پەقەت {name} نىلا ئىزدەڭ",
    "Loading more results …" : "تېخىمۇ كۆپ نەتىجىلەرنى يۈكلەۋاتىدۇ…",
    "Forgot password?" : "پارولنى ئۇنتۇپ قالدىڭىزمۇ؟",
    "Back to login form" : "كىرىش جەدۋىلىگە قايتىڭ",
    "Back" : "قايتىش",
    "Login form is disabled." : "كىرىش جەدۋىلى چەكلەنگەن.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud كىرىش جەدۋىلى چەكلەنگەن. ئەگەر بار بولسا باشقا كىرىش تاللانمىسىنى ئىشلىتىڭ ياكى باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
    "More actions" : "تېخىمۇ كۆپ ھەرىكەت",
    "Security warning" : "بىخەتەرلىك ئاگاھلاندۇرۇشى",
    "Storage & database" : "ساقلاش ۋە ساندان",
    "Data folder" : "سانلىق مەلۇمات قىسقۇچ",
    "Install and activate additional PHP modules to choose other database types." : "باشقا PHP بۆلەكلىرىنى ئورنىتىپ قوزغىتىپ باشقا ساندان تىپلىرىنى تاللاڭ.",
    "For more details check out the documentation." : "تېخىمۇ كۆپ تەپسىلاتلارنى بۇ ھۆججەتتىن كۆرۈڭ.",
    "Performance warning" : "ئىقتىدار ئاگاھلاندۇرۇشى",
    "You chose SQLite as database." : "SQLite نى ساندان قىلىپ تاللىدىڭىز.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite پەقەت ئەڭ كىچىك ۋە تەرەققىيات مىساللىرى ئۈچۈن ئىشلىتىلىشى كېرەك. ئىشلەپچىقىرىش ئۈچۈن باشقا ساندان ئارقا سەھنىسىنى تەۋسىيە قىلىمىز.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "ئەگەر ھۆججەتلەرنى ماسقەدەملەش ئۈچۈن خېرىدار ئىشلەتسىڭىز ، SQLite نى ئىشلىتىش تولىمۇ ئۈمىدسىزلىنىدۇ.",
    "Database user" : "ساندان ئىشلەتكۈچى",
    "Database password" : "ساندان پارولى",
    "Database name" : "ساندان ئىسمى",
    "Database tablespace" : "ساندان جەدۋىلى",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "باش ئاپپارات ئىسمى بىلەن بىللە پورت نومۇرىنى بەلگىلىۈڭ (مەسىلەن ، localhost: 5432).",
    "Database host" : "ساندان مۇلازىمېتىرى",
    "Installing …" : "قاچىلاش…",
    "Install" : "قاچىلاش",
    "Need help?" : "ياردەمگە ئېھتىياجلىقمۇ؟",
    "See the documentation" : "ھۆججەتلەرنى كۆرۈڭ",
    "{name} version {version} and above" : "{name} نەشرى {version} ۋە ئۇنىڭدىن يۇقىرى",
    "This browser is not supported" : "بۇ توركۆرگۈچنى قوللىمايدۇ",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "توركۆرگۈڭىزنى قوللىمايدۇ. يېڭى نەشرىگە ياكى قوللايدىغان نەشرىگە يېڭىلاڭ.",
    "Continue with this unsupported browser" : "بۇ قوللىمايدىغان توركۆرگۈ بىلەن داۋاملاشتۇرۇڭ",
    "Supported versions" : "قوللايدىغان نەشرى",
    "Search {types} …" : "ئىزدەش {types}…",
    "Choose {file}" : "{file} نى تاللاڭ",
    "Choose" : "تاللاڭ",
    "Copy to {target}" : "{target} غا كۆچۈرۈڭ",
    "Copy" : "كۆچۈرۈڭ",
    "Move to {target}" : "{target} يۆتكەڭ",
    "Move" : "Move",
    "OK" : "جەزملە",
    "read-only" : "پەقەت ئوقۇشقىلا بولىدۇ",
    "One file conflict" : "بىر ھۆججەت توقۇنۇشى",
    "New Files" : "يېڭى ھۆججەتلەر",
    "Already existing files" : "مەۋجۇت ھۆججەتلەر",
    "Which files do you want to keep?" : "قايسى ھۆججەتلەرنى ساقلىماقچى؟",
    "If you select both versions, the copied file will have a number added to its name." : "ئەگەر ھەر ئىككى نەشرىنى تاللىسىڭىز ، كۆچۈرۈلگەن ھۆججەتنىڭ نامىغا بىر سان قوشۇلىدۇ.",
    "Cancel" : "ۋاز كەچ",
    "Continue" : "داۋاملاشتۇر",
    "(all selected)" : "(ھەممىسى تاللانغان)",
    "({count} selected)" : "({count} تاللانغان)",
    "Error loading file exists template" : "ھۆججەت يۈكلەشتە خاتالىق بار",
    "Saving …" : "Saving…",
    "seconds ago" : "سېكۇنت بۇرۇن",
    "Connection to server lost" : "مۇلازىمېتىرغا ئۇلىنىش يوقاپ كەتتى",
    "Add to a project" : "بىر تۈرگە قوشۇڭ",
    "Show details" : "تەپسىلاتلارنى كۆرسەت",
    "Hide details" : "تەپسىلاتلارنى يوشۇرۇش",
    "Rename project" : "تۈرنىڭ نامىنى ئۆزگەرتىش",
    "Failed to rename the project" : "بۇ تۈرنىڭ نامىنى ئۆزگەرتەلمىدى",
    "Failed to create a project" : "بىر تۈر قۇرالمىدى",
    "Failed to add the item to the project" : "بۇ تۈرگە تۈر قوشالمىدى",
    "Connect items to a project to make them easier to find" : "نەرسىلەرنى تېپىشقا قۇلايلىق بولسۇن ئۈچۈن تۈرلەرگە ئۇلاڭ",
    "Type to search for existing projects" : "مەۋجۇت تۈرلەرنى ئىزدەش ئۈچۈن كىرگۈزۈڭ",
    "New in" : "يېڭى",
    "View changelog" : "Changelog نى كۆرۈڭ",
    "No action available" : "ھەرىكەت يوق",
    "Error fetching contact actions" : "ئالاقىلىشىش ھەرىكىتىنى ئېلىپ بېرىشتا خاتالىق",
    "Close \"{dialogTitle}\" dialog" : "\"{dialogTitle}\" سۆزلىشىش رامكىسىنى تاقاڭ",
    "Email length is at max (255)" : "ئېلېكترونلۇق خەتنىڭ ئۇزۇنلۇقى ئەڭ يۇقىرى بولغاندا (255)",
    "Non-existing tag #{tag}" : "مەۋجۇت بولمىغان بەلگە # {tag}",
    "Restricted" : "چەكلەنگەن",
    "Invisible" : "كۆرۈنمەيدۇ",
    "Delete" : "ئۆچۈر",
    "Rename" : "ئات ئۆزگەرت",
    "Collaborative tags" : "ھەمكارلىق بەلگىسى",
    "No tags found" : "خەتكۈچ تېپىلمىدى",
    "Personal" : "شەخسىي",
    "Accounts" : "ھېسابات",
    "Admin" : "باشقۇرغۇچى",
    "Help" : "ياردەم",
    "Access forbidden" : "زىيارەت قىلىش چەكلەنگەن",
    "Back to %s" : "% S گە قايتىش",
    "Page not found" : "بەت تېپىلمىدى",
    "The page could not be found on the server or you may not be allowed to view it." : "بۇ بەتنى مۇلازىمېتىردىن تاپقىلى بولمايدۇ ياكى ئۇنى كۆرۈشكە رۇخسەت قىلىنماسلىقىڭىز مۇمكىن.",
    "Too many requests" : "بەك كۆپ تەلەپ",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "تورىڭىزدىن بەك كۆپ تەلەپلەر بار ئىدى. كېيىن قايتا سىناڭ ياكى باشقۇرغۇچى بىلەن ئالاقىلىشىڭ.",
    "Error" : "خاتالىق",
    "Internal Server Error" : "ئىچكى مۇلازىمېتىر خاتالىقى",
    "The server was unable to complete your request." : "مۇلازىمېتىر تەلىپىڭىزنى ئورۇندىيالمىدى.",
    "If this happens again, please send the technical details below to the server administrator." : "ئەگەر بۇ ئىش قايتا يۈز بەرسە ، تۆۋەندىكى تېخنىكىلىق تەپسىلاتلارنى مۇلازىمېتىر باشقۇرغۇچىغا ئەۋەتىڭ.",
    "More details can be found in the server log." : "تېخىمۇ كۆپ تەپسىلاتلارنى مۇلازىمېتىر خاتىرىسىدىن تاپقىلى بولىدۇ.",
    "For more details see the documentation ↗." : "تېخىمۇ كۆپ تەپسىلاتلارنى بۇ ھۆججەتتىن كۆرۈڭ.",
    "Technical details" : "تېخنىكىلىق تەپسىلاتلار",
    "Remote Address: %s" : "يىراقتىكى ئادرېس:% s",
    "Request ID: %s" : "تەلەپ كىملىكى:% s",
    "Type: %s" : "تىپى:% s",
    "Code: %s" : "كود:% s",
    "Message: %s" : "ئۇچۇر:% s",
    "File: %s" : "ھۆججەت:% s",
    "Line: %s" : "Line:% s",
    "Trace" : "ئىز",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Nextcloud نى قايتا قاچىلىماقچى بولۇۋاتقان ئوخشايسىز. ئەمما CAN_INSTALL ھۆججىتى سەپلىمە مۇندەرىجىڭىزدە كەم. داۋاملاشتۇرۇش ئۈچۈن ھۆججەت قىسقۇچىڭىزدا CAN_INSTALL ھۆججىتىنى قۇرۇڭ.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "سەپلىمە ھۆججەت قىسقۇچىدىن CAN_INSTALL نى ئۆچۈرەلمىدى. بۇ ھۆججەتنى قولدا ئۆچۈرۈڭ.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "بۇ پروگرامما توغرا مەشغۇلات ئۈچۈن JavaScript تەلەپ قىلىدۇ. {linkstart} Java JavaScript {linkend} نى قوزغىتىپ ، بەتنى قايتا يۈكلەڭ.",
    "Skip to main content" : "ئاساسلىق مەزمۇنغا ئاتلاڭ",
    "Skip to navigation of app" : "ئەپنىڭ يول باشلىشىغا ئاتلاڭ",
    "Go to %s" : "% S گە بېرىڭ",
    "Get your own free account" : "ئۆزىڭىزنىڭ ھەقسىز ھېساباتىغا ئېرىشىڭ",
    "Connect to your account" : "ھېساباتىڭىزغا ئۇلاڭ",
    "Please log in before granting %1$s access to your %2$s account." : "%2 $ s ھېساباتىڭىزغا%1 $ s ئىجازەت بېرىشتىن بۇرۇن كىرىڭ.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "ئەگەر سىز يېڭى ئۈسكۈنە ياكى ئەپ ئورنىتىشنى ئويلىمىسىڭىز ، بىرەيلەن سىزنى ئالداش ئارقىلىق ئۇلارنى سانلىق مەلۇماتلىرىڭىزغا ئېرىشمەكچى بولۇۋاتىدۇ. بۇ ئەھۋالدا داۋاملاشتۇرماڭ ، ئەكسىچە سىستېما باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
    "App password" : "ئەپ پارولى",
    "Grant access" : "زىيارەت قىلىش ھوقۇقى",
    "Alternative log in using app password" : "ئەپ مەخپىي نومۇرىنى ئىشلىتىپ باشقا تىزىمغا كىرىش",
    "Account access" : "ھېساباتقا كىرىش",
    "Currently logged in as %1$s (%2$s)." : "ھازىر%1 $ s (%2 $ s) سۈپىتىدە تىزىمغا كىردى.",
    "You are about to grant %1$s access to your %2$s account." : "سىز%2 $ s ھېساباتىڭىزغا%1 $ s ئىجازەت بەرمەكچى بولۇۋاتىسىز.",
    "Account connected" : "ھېسابات ئۇلاندى",
    "Your client should now be connected!" : "خېرىدارىڭىز ھازىر ئۇلىنىشى كېرەك!",
    "You can close this window." : "بۇ كۆزنەكنى ياپالايسىز.",
    "Previous" : "ئالدىنقى",
    "This share is password-protected" : "بۇ ئورتاقلىشىش مەخپىي نومۇر بىلەن قوغدىلىدۇ",
    "The password is wrong or expired. Please try again or request a new one." : "پارول خاتا ياكى ۋاقتى ئۆتكەن. قايتا سىناڭ ياكى يېڭىنى تەلەپ قىلىڭ.",
    "Please type in your email address to request a temporary password" : "ۋاقىتلىق پارول تەلەپ قىلىش ئۈچۈن ئېلېكترونلۇق خەت ئادرېسىڭىزنى كىرگۈزۈڭ",
    "Email address" : "ئېلخەت ئادرېسى",
    "Password sent!" : "پارول ئەۋەتىلدى!",
    "You are not authorized to request a password for this share" : "بۇ ئورتاقلىشىش ئۈچۈن پارول تەلەپ قىلىش ھوقۇقىڭىز يوق",
    "Two-factor authentication" : "ئىككى ئامىللىق دەلىللەش",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "ھېساباتىڭىزغا بىخەتەرلىك كۈچەيتىلگەن. دەلىللەشنىڭ ئىككىنچى ئامىلىنى تاللاڭ:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "قوزغىتىلغان ئىككى ئامىللىق ئاپتوماتىك ئۇسۇلدىن كەم دېگەندە بىرنى يۈكلىيەلمىدىڭىز. باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "ئىككى ئامىللىق دەلىللەش ئىجرا قىلىنىدۇ ، ئەمما ھېساباتىڭىزغا تەڭشەلمىدى. ياردەم ئۈچۈن باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "ئىككى ئامىللىق دەلىللەش ئىجرا قىلىنىدۇ ، ئەمما ھېساباتىڭىزغا تەڭشەلمىدى. داۋاملىق ئىككى ئامىللىق دەلىللەشنى تەڭشەڭ.",
    "Set up two-factor authentication" : "ئىككى ئامىللىق دەلىللەشنى ئورنىتىڭ",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "ئىككى ئامىللىق دەلىللەش ئىجرا قىلىنىدۇ ، ئەمما ھېساباتىڭىزغا تەڭشەلمىدى. زاپاسلاش كودىڭىزدىن بىرنى ئىشلىتىپ كىرىڭ ياكى باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
    "Use backup code" : "زاپاسلاش كودىنى ئىشلىتىڭ",
    "Cancel login" : "كىرىشنى ئەمەلدىن قالدۇرۇڭ",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "ھېساباتىڭىز ئۈچۈن كۈچەيتىلگەن بىخەتەرلىك ئىجرا قىلىنىدۇ. قايسى تەمىنلىگۈچىنى تەڭشەشنى تاللاڭ:",
    "Error while validating your second factor" : "ئىككىنچى ئامىلىنى دەلىللەۋاتقاندا خاتالىق",
    "Access through untrusted domain" : "ئىشەنچسىز دائىرە ئارقىلىق زىيارەت قىلىڭ",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ. ئەگەر سىز باشقۇرغۇچى بولسىڭىز ، config.sample.php دىكى مىسالغا ئوخشاش config / config.php دىكى «ئىشەنچلىك_ دائىرە» تەڭشىكىنى تەھرىرلەڭ.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "بۇنى قانداق تەڭشەش توغرىسىدىكى تېخىمۇ كۆپ ئۇچۇرلارنى%1 $ sdocumentation%2 $ s دىن تاپقىلى بولىدۇ.",
    "App update required" : "ئەپ يېڭىلاش تەلەپ قىلىنىدۇ",
    "%1$s will be updated to version %2$s" : "%1 $ s%2 $ s نەشرىگە يېڭىلىنىدۇ",
    "The following apps will be updated:" : "تۆۋەندىكى ئەپلەر يېڭىلىنىدۇ:",
    "These incompatible apps will be disabled:" : "ماس كەلمەيدىغان بۇ دېتاللار چەكلىنىدۇ:",
    "The theme %s has been disabled." : "باشتېما% s چەكلەنگەن.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "داۋاملاشتۇرۇشتىن بۇرۇن ساندان ، سەپلىمە ھۆججەت قىسقۇچ ۋە سانلىق مەلۇمات قىسقۇچنىڭ زاپاسلانغانلىقىنى جەزملەشتۈرۈڭ.",
    "Start update" : "يېڭىلاشنى باشلاڭ",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "چوڭراق قاچىلاش ۋاقتىدىن ساقلىنىش ئۈچۈن ، قاچىلاش مۇندەرىجىسىدىن تۆۋەندىكى بۇيرۇقنى ئىجرا قىلالايسىز:",
    "Detailed logs" : "تەپسىلىي خاتىرىلەر",
    "Update needed" : "يېڭىلاش لازىم",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "بۇيرۇق قۇرىنى يېڭىلاشنى ئىشلىتىڭ ، چۈنكى سىزنىڭ 50 دىن ئارتۇق ھېساباتىڭىز بار.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "ياردەم ئۈچۈن <a target = \"_ blank\" rel = \"noreferrer noopener\" href = \"% s\"> ھۆججەت </a> نى كۆرۈڭ.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "مەن تور UI ئارقىلىق يېڭىلاشنى داۋاملاشتۇرسام ، خەتەرنىڭ بارلىقىنى ، تەلەپنىڭ ۋاقىت چەكلىمىسىگە ئۇچراپ ، سانلىق مەلۇماتلارنىڭ يوقاپ كېتىشىنى كەلتۈرۈپ چىقىرىدىغانلىقىنى بىلىمەن ، ئەمما مېنىڭ زاپاسلاش ئىقتىدارىم بار ، مەغلۇپ بولغان ئەھۋال ئاستىدا مىسالىمنى قانداق ئەسلىگە كەلتۈرۈشنى بىلىمەن.",
    "Upgrade via web on my own risk" : "ئۆزۈمنىڭ خەتىرىگە ئاساسەن تور ئارقىلىق يېڭىلاش",
    "Maintenance mode" : "ئاسراش ھالىتى",
    "This %s instance is currently in maintenance mode, which may take a while." : "بۇ% s مىسال ھازىر ئاسراش ھالىتىدە بولۇپ ، بۇنىڭغا بىر ئاز ۋاقىت كېتىشى مۇمكىن.",
    "This page will refresh itself when the instance is available again." : "مىسال قايتا بولغاندا بۇ بەت ئۆزىنى يېڭىلايدۇ.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "ئەگەر بۇ ئۇچۇر داۋاملاشسا ياكى ئويلىمىغان يەردىن سىستېما باشقۇرغۇچى بىلەن ئالاقىلىشىڭ.",
    "Error occurred while checking server setup" : "مۇلازىمېتىرنىڭ تەڭشىكىنى تەكشۈرگەندە خاتالىق كۆرۈلدى",
    "For more details see the {linkstart}documentation ↗{linkend}." : "تېخىمۇ كۆپ تەپسىلاتلارنى {linkstart} ھۆججەت ↗ {linkend} see دىن كۆرۈڭ.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "تور كۆرگۈڭىزدە ۋە كۆچمە ئەپلەر بىلەن پاراڭلىشىش ، سىنلىق سۆزلىشىش ، ئېكراندىن ئورتاقلىشىش ، توردىكى ئۇچرىشىش ۋە تور يىغىنى.",
    "You have not added any info yet" : "سىز تېخى ھېچقانداق ئۇچۇر قوشمىدىڭىز",
    "{user} has not added any info yet" : "{user} تېخى ھېچقانداق ئۇچۇر قوشمىدى",
    "Error opening the user status modal, try hard refreshing the page" : "ئىشلەتكۈچى ھالىتى ھالىتىنى ئېچىشتا خاتالىق ، بەتنى يېڭىلاشنى سىناپ بېقىڭ",
    "Edit Profile" : "ئارخىپنى تەھرىرلەش",
    "The headline and about sections will show up here" : "ماۋزۇ ۋە بۆلەكلەر بۇ يەردە كۆرسىتىلىدۇ",
    "Very weak password" : "پارول بەك ئاجىز",
    "Weak password" : "پارول ئاجىز",
    "So-so password" : "شۇڭا مەخپىي نومۇر",
    "Good password" : "ياخشى پارول",
    "Strong password" : "كۈچلۈك پارول",
    "Profile not found" : "ئارخىپ تېپىلمىدى",
    "The profile does not exist." : "ئارخىپ مەۋجۇت ئەمەس.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".Htaccess ھۆججىتى ئىشلىمىگەچكە ، سانلىق مەلۇمات مۇندەرىجىسىڭىز ۋە ھۆججەتلىرىڭىزنى توردىن زىيارەت قىلىشىڭىز مۇمكىن.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "مۇلازىمېتىرىڭىزنى قانداق تەڭشەش كېرەكلىكى توغرىسىدىكى ئۇچۇرلارنى <a href = \"% s\" target = \"_ blank\" rel = \"noreferrer noopener\"> ھۆججەت </a> دىن كۆرۈڭ.",
    "Show password" : "پارولنى كۆرسەت",
    "Toggle password visibility" : "پارولنىڭ كۆرۈنۈشچانلىقىنى توغرىلاڭ",
    "Configure the database" : "سانداننى سەپلەڭ",
    "Only %s is available." : "پەقەت% s نىلا ئىشلەتكىلى بولىدۇ.",
    "Database account" : "ساندان ھېساباتى",
    "Direct link copied to clipboard" : "چاپلاش تاختىسىغا كۆچۈرۈلگەن بىۋاسىتە ئۇلىنىش"
},
"nplurals=2; plural=(n != 1);");
